@@ -1,11 +1,10 @@
-if (require(rgdal) == FALSE)
-	q()
-
 # for validity of covariance functions on the sphere, see also:
 # DOI 10.1007/s11004-011-9344-7
 # http://mypage.iu.edu/~srobeson/Pubs/variogram_sphere_mathgeo_2011.pdf
 
-library(sp)
+suppressPackageStartupMessages(library(sp))
+suppressPackageStartupMessages(library(rgdal))
+suppressPackageStartupMessages(library(fields))
 data(meuse)
 coordinates(meuse) = ~x+y
 proj4string(meuse) = CRS("+init=epsg:28992")
@@ -21,7 +20,6 @@ cloud2 = variogram(log(zinc)~1, meuse.ll, cloud=T, cutoff=6)
 plot(cloud1$dist/1000, cloud2$dist, xlab="Amersfoort, km", ylab = "Long/lat")
 abline(0,1)
 
-if (require(fields)) {
   data(ozone2)
   oz = SpatialPointsDataFrame(ozone2$lon.lat, 
 		  data.frame(t(ozone2$y)), 
@@ -30,7 +28,6 @@ if (require(fields)) {
   utm16 = CRS("+proj=utm +zone=16 +ellps=WGS84")
   oz.utm = spTransform(oz, utm16)
   variogram(X870731~1,oz.utm[!is.na(oz$X870731),])
-}
 
 # Timothy Hilton, r-sig-geo, Sept 14, 2008:
 
